# ZhigeTools
[English](README.md)    |    [简体中文](README-zh.md)
## Introduction
ZhigeTools is an open-source Python toolkit that provides a collection of utility functions for daily work. It is designed to simplify common tasks by offering easy-to-use wrappers.

## Installation
```
pip install zhigetools
```

## Features
- [x] Character Conversion Tools

    base_to_number
    - Converts a string to a number, supporting custom bases and custom symbols for the base.
    ``` python
    from zhige_tools.base_converter import base_to_number
    ```
    number_to_base
    - Converts a number to a string, supporting custom bases and custom symbols for the base.
    ``` python
    from zhige_tools.base_converter import number_to_base
    ```

## Changelog
- **2021.10.25 v0.1.0**

   Initial release

- **2021.10.25：v0.1.1**

   Added function hints, updated README.md

